Module: TDriverVerify

Included in:
MattiVerify
Defined in:
lib/tdriver/verify/verify.rb

Overview

Copyright © 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved. Contact: Nokia Corporation ([email protected])

This file is part of Testability Driver.

If you have questions regarding the use of this file, please contact Nokia at [email protected] .

This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License version 2.1 as published by the Free Software Foundation and appearing in the file LICENSE.LGPL included in the packaging of this file.

Constant Summary collapse

TIMEOUT_CYCLE_SECONDS =
0.1
@@on_error_verify_block =
nil

Instance Method Summary collapse

Instance Method Details

#execute_on_error_verify_blockObject



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/tdriver/verify/verify.rb', line 40

def execute_on_error_verify_block

  unless @@on_error_verify_block.nil?

    begin

      @@on_error_verify_block.call

    rescue Exception

      raise $!.class, "Exception was raised while executing on_error_verify_block. Reason: #{ $!.message.to_s }"

    end

  else

    raise ArgumentError, 'No verify block defined with on_error_verify_block method'

  end

end

#on_error_verify_block(&block) ⇒ Object

Raises:

  • (ArgumentError)


26
27
28
29
30
31
32
# File 'lib/tdriver/verify/verify.rb', line 26

def on_error_verify_block( &block )

  raise ArgumentError.new( "No verify block given" ) unless block_given?

  @@on_error_verify_block = block

end

#reset_on_error_verify_blockObject



34
35
36
37
38
# File 'lib/tdriver/verify/verify.rb', line 34

def reset_on_error_verify_block

  @@on_error_verify_block = nil

end

#verify(timeout = nil, message = nil, &block) ⇒ Object

Verifies that the block given to this method evaluates without throwing any exceptions. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/tdriver/verify/verify.rb', line 73

def verify( timeout = nil, message = nil, &block )

  begin

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        yield

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
          
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify;"

  nil

end

#verify_equal(expected_value, timeout = nil, message = nil, &block) ⇒ Object

Verifies that result of given block equals to expected value. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

expected

Expected result value of the block

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
# File 'lib/tdriver/verify/verify.rb', line 609

def verify_equal( expected_value, timeout = nil, message = nil, &block )

  begin

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield does not equal with expected value 
        raise MobyBase::VerificationError unless result == expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The value was not equal to #{ expected_value }. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_equal;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_equal;"

  nil

end

#verify_false(timeout = nil, message = nil, &block) ⇒ Object

Verifies that the block given to this method evaluates to false. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
# File 'lib/tdriver/verify/verify.rb', line 469

def verify_false( timeout = nil, message = nil, &block )

  begin

    # expected result
    expected_value = false

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield does not equal with expected value 
        raise MobyBase::VerificationError unless result == expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The block did not return #{ expected_value }. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_false;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_false;"

  nil

end

#verify_greater(expected_value, timeout = nil, message = nil, &block) ⇒ Object

Verifies that result of the given block is greater than expected value. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

expected

Expected result value of the block

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
# File 'lib/tdriver/verify/verify.rb', line 883

def verify_greater( expected_value, timeout = nil, message = nil, &block )

  begin

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield is greater than expected value 
        raise MobyBase::VerificationError unless result > expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The value vas not greater than #{ expected_value }. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_greater;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_greater;"

  nil

end

#verify_less(expected_value, timeout = nil, message = nil, &block) ⇒ Object

Verifies that result of the given block is less than expected value. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

expected

Expected result value of the block

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
# File 'lib/tdriver/verify/verify.rb', line 746

def verify_less( expected_value, timeout = nil, message = nil, &block )

  begin

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield is less than expected value 
        raise MobyBase::VerificationError unless result < expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The value was not less than #{ expected_value }. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_less;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_less;"

  nil

end

#verify_not(timeout = nil, message = nil, &block) ⇒ Object

Verifies that the block given to this method throws an exception while being evaluated. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/tdriver/verify/verify.rb', line 197

def verify_not( timeout = nil, message = nil, &block )

  begin

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      counter = ref_counter

      begin
      
        # execute code block
        result = yield

      rescue

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )
      
        # break loop if exceptions thrown
        break

      end

      # refresh and retry unless timeout exceeded
      raise $! if Time.now > timeout_end_time
      
      # retry interval
      sleep TIMEOUT_CYCLE_SECONDS

      # refresh suts
      refresh_suts if counter == ref_counter
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The block did not raise exception. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_not;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_not;"

  nil

end

#verify_regexp(expected_value, timeout = nil, message = nil, &block) ⇒ Object

Verifies that the block given to return value matches with expected regular expression pattern. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

expected

Regular expression

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

TypeError

if block result not type of String.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'lib/tdriver/verify/verify.rb', line 1021

def verify_regexp( expected_value, timeout = nil, message = nil, &block )

  begin

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout
  
    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # verify that arguments was given in correct format
    expected_value.check_type Regexp, "wrong argument type $1 for expected result (expected $2)"

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield does not match with expected value regexp 
        raise MobyBase::VerificationError unless result =~ expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The return value of block did not match with #{ expected_value.inspect } pattern. Block returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_regexp;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_regexp;"

  nil

end

#verify_signal(timeout, signal_name, message = nil, &block) ⇒ Object

Verifies that the given signal is emitted.

params

timeout

Integer, defining the amount of seconds during which the verification must pass.

signal_name

String, name of the signal

message

(optional) A String that is displayed as additional information if the verification fails.

block

code to execute while listening signals

returns

nil

raises

ArgumentError

message or signal_name was not a String or timeout a non negative Integer

VerificationError

The verification failed.



1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
# File 'lib/tdriver/verify/verify.rb', line 1160

def verify_signal( timeout, signal_name, message = nil, &block )

  begin

    logging_enabled = $logger.enabled

    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type Integer, 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    verify_caller = caller(1).first.to_s

    # wait for the signal
    begin

      wait_for_signal( timeout, signal_name, &block )

    rescue

      error_msg = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source(verify_caller) }"
      error_msg << "The signal #{ signal_name } was not emitted in #{ timeout } seconds.\nNested exception:\n#{ $!.inspect }"

      raise MobyBase::VerificationError, error_msg

    end

  rescue

    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    $logger.enabled = logging_enabled

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s } using timeout '#{ timeout }.;#{ kind_of?(MobyBase::SUT) ? id.to_s + ';sut' : ';' };{};verify_signal;#{ signal_name }"

    raise

  ensure
  
    $logger.enabled = logging_enabled
    
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_signal;#{ signal_name }"
  
  nil

end

#verify_true(timeout = nil, message = nil, &block) ⇒ Object

Verifies that the block given to this method evaluates to true. Verification is synchronized with all connected suts. If this method is called for a sut, synchronization is only done with that sut.

params

timeout

(optional) Integer defining the amount of seconds during which the verification must pass.

message

(optional) A String that is displayed as additional information if the verification fails.

returns

nil

raises

ArgumentError

message was not a String or timeout an integer, or no block was given.

VerificationError

The verification failed.

RuntimeError

An unexpected error was encountered during verification.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/tdriver/verify/verify.rb', line 330

def verify_true( timeout = nil, message = nil, &block )

  begin

    # expected result
    expected_value = true

    # determine name of caller method
    verify_caller = caller( 1 ).first.to_s

    # store orignal logging state
    logging_enabled = $logger.enabled

    # disable behaviour logging
    $logger.enabled = false

    # ensure that timeout is either nil or type of integer
    timeout.check_type [ Integer, NilClass ], 'wrong argument type $1 for timeout (expected $2)'

    # ensure that message is either nil or type of string
    message.check_type [ String, NilClass ], 'wrong argument type $1 for exception message (expected $2)'

    # verify that block was given
    raise LocalJumpError, 'unable to verify due to no code block was given' unless block_given?

    # convert timeout to integer, nil will be zero
    timeout = get_timeout( timeout )

    # verify that timeout is valid
    timeout.not_negative 'timeout value cannot be negative'

    # calculate the time when timeout exceeds
    timeout_end_time = Time.now + timeout

    # convert message to string, nil will be empty string
    message = message.to_s

    # add double quotation and trailing whitespace if not empty string
    message = "#{ message.inspect } " if message.length > 0

    # store original timeout value
    original_timeout_value = TDriver::TestObjectFactory.timeout

    # set the testobject timeout to 0 for the duration of the verify call
    TDriver::TestObjectFactory.timeout = 0

    # result container
    result = nil

    loop do
    
      begin
      
        counter = ref_counter

        # execute code block
        result = yield

        # raise exception if result of yield does not equal with expected value 
        raise MobyBase::VerificationError unless result == expected_value

        # break loop if no exceptions thrown
        break

      rescue 

        raise if $!.kind_of?( MobyBase::ContinuousVerificationError )

        # refresh and retry unless timeout exceeded
        raise $! if Time.now > timeout_end_time
        
        # retry interval
        sleep TIMEOUT_CYCLE_SECONDS

        # refresh suts
        refresh_suts if counter == ref_counter
      
      end # begin
    
    end # do loop
      
  rescue

    # restore logger state
    $logger.enabled = logging_enabled

    # execute on verification error code block
    execute_on_error_verify_block unless @@on_error_verify_block.nil?

    # process the exception
    if $!.kind_of?( MobyBase::ContinuousVerificationError )
    
      raise
  
    elsif $!.kind_of?( MobyBase::VerificationError )
    
      error_message = "Verification #{ message }at #{ verify_caller } failed: #{ MobyUtil::KernelHelper.find_source( verify_caller ) }"
      error_message << "The block did not return #{ expected_value }. It returned: #{ result.inspect }"
      
    else
    
      error_message = "Verification #{ message }at #{ verify_caller } failed as an exception was thrown when the verification block was executed"
      error_message << "#{ MobyUtil::KernelHelper.find_source( verify_caller ) }\nDetails: \n#{ $!.inspect }"
    
    end

    $logger.behaviour "FAIL;Verification #{ message }failed: #{ $!.to_s }.\n #{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_true;"

    # raise the exception
    raise MobyBase::VerificationError, error_message
     
  ensure

    # restore original test object factory timeout value 
    TDriver::TestObjectFactory.timeout = original_timeout_value

    # restore logger state
    $logger.enabled = logging_enabled
  
  end

  $logger.behaviour "PASS;Verification #{ message }at #{ verify_caller } was successful#{ timeout.nil? ? '' : ' using timeout ' + timeout.to_s }.;#{ kind_of?( MobyBase::SUT ) ? id.to_s + ';sut' : ';' };{};verify_true;"

  nil

end